antares.apps.message.api package
================================

Submodules
----------

antares.apps.message.api.message\_api module
--------------------------------------------

.. automodule:: antares.apps.message.api.message_api
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.message.api.message\_details\_api module
-----------------------------------------------------

.. automodule:: antares.apps.message.api.message_details_api
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.message.api
   :members:
   :undoc-members:
   :show-inheritance:
